# example.js

``` javascript
function getTemplate(templateName) {
	return require("./templates/"+templateName);
}
console.log(getTemplate("a"));
console.log(getTemplate("b"));
```

# templates/

* a.js
* b.js
* c.js

All templates are of this pattern:

``` javascript
module.exports = function() {
	return "This text was generated by template X";
}
```

# js/output.js

``` javascript
/******/(function(modules) {
/******/	var installedModules = {};
/******/	function require(moduleId) {
/******/		if(installedModules[moduleId])
/******/			return installedModules[moduleId].exports;
/******/		var module = installedModules[moduleId] = {
/******/			exports: {}
/******/		};
/******/		modules[moduleId](module, module.exports, require);
/******/		return module.exports;
/******/	}
/******/	require.ensure = function(chunkId, callback) {
/******/		callback(require);
/******/	};
/******/	return require(0);
/******/})
/******/({
/******/0: function(module, exports, require) {

function getTemplate(templateName) {
	return require(1)("./"+templateName);
}
console.log(getTemplate("a"));
console.log(getTemplate("b"));

/******/},
/******/
/******/1: function(module, exports, require) {

/***/module.exports = function(name) {
/***/	var map = {"./b.js":3,"./a.js":2,"./c.js":4};
/***/	return require(map[name]||map[name+".web.js"]||map[name+".js"]);
/***/};

/******/},
/******/
/******/2: function(module, exports, require) {

module.exports = function() {
	return "This text was generated by template A";
}

/******/},
/******/
/******/3: function(module, exports, require) {

module.exports = function() {
	return "This text was generated by template B";
}

/******/},
/******/
/******/4: function(module, exports, require) {

module.exports = function() {
	return "This text was generated by template C";
}

/******/},
/******/
/******/})
```

# Info

## Uncompressed

``` javascript
{ chunkCount: 1,
  modulesCount: 5,
  modulesIncludingDuplicates: 5,
  modulesPerChunk: 5,
  modulesFirstChunk: 5,
  fileSizes: { 'output.js': 1454 } }
```

## Minimized (uglify-js, no zip)

``` javascript
{ chunkCount: 1,
  modulesCount: 5,
  modulesIncludingDuplicates: 5,
  modulesPerChunk: 5,
  modulesFirstChunk: 5,
  fileSizes: { 'output.js': 650 } }
```

# Code Splitting

See [this example combined with code splitting](code-splitted-require.context)
